# Copyright 1999-2011 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/dev-libs/icu/Attic/icu-4.4.2.ebuild,v 1.10 2011/04/03 11:54:10 arfrever dead $

EAPI="3"

inherit eutils flag-o-matic versionator

MAJOR_MINOR_VERSION="$(get_version_component_range 1-2)"
MICRO_VERSION="$(get_version_component_range 3)"

DESCRIPTION="International Components for Unicode (4.4 libs only"
HOMEPAGE="http://www.icu-project.org/"

BASE_URI="http://download.icu-project.org/files/icu4c/${PV}"
DOCS_BASE_URI="http://download.icu-project.org/files/icu4c/${MAJOR_MINOR_VERSION}"
SRC_ARCHIVE="icu4c-${PV//./_}-src.tgz"

SRC_URI="${BASE_URI}/${SRC_ARCHIVE}"

LICENSE="BSD"
SLOT="4.4"
KEYWORDS="alpha amd64 arm hppa ia64 ~mips ppc ppc64 s390 sh sparc x86 ~x86-fbsd"
IUSE="debug"

DEPEND=""
RDEPEND=""

S="${WORKDIR}/${PN}/source"

QA_DT_NEEDED="/usr/lib.*/libicudata.so.${MAJOR_MINOR_VERSION/./}.${MICRO_VERSION:-0}"

src_unpack() {
	unpack "${SRC_ARCHIVE}"
}

src_prepare() {
	# Do not hardcode used CFLAGS, LDFLAGS etc. into icu-config
	# Bug 202059
	# https://bugs.icu-project.org/trac/ticket/6102
	for x in ARFLAGS CFLAGS CPPFLAGS CXXFLAGS FFLAGS LDFLAGS; do
		sed -i -e "/^${x} =.*/s:@${x}@::" "config/Makefile.inc.in" || die "sed failed"
	done

	epatch "${FILESDIR}/${PN}-4.4.1-pkgdata.patch"
	epatch "${FILESDIR}/${PN}-4.4.1-et_EE.patch"
	epatch "${FILESDIR}/${PN}-4.4.1-arm.patch"
	epatch "${FILESDIR}/${P}-gcc-4.5.patch"
}

src_configure() {
	append-flags -fno-strict-aliasing

	econf \
		$(use_enable debug)
}

src_test() {
	emake check || die "emake check failed"
}

src_install() {
	emake DESTDIR="${D}" install || die "emake install failed"
	rm -rf "${D}"/usr/bin
	rm -rf "${D}"/usr/include
	rm -rf "${D}"/usr/lib*/*.so
	rm -rf "${D}"/usr/lib*/icu
	rm -rf "${D}"/usr/sbin
	rm -rf "${D}"/usr/share
	#die
	dohtml ../readme.html
	dodoc ../unicode-license.txt
}
